<?php
/*------------------------------------------------------------------------------
  $Id$

  AbanteCart, Ideal OpenSource Ecommerce Solution
  http://www.AbanteCart.com

  Copyright © 2011 Belavier Commerce LLC

  This source file is subject to Open Software License (OSL 3.0)
  License details is bundled with this package in the file LICENSE.txt.
  It is also available at this URL:
  <http://www.opensource.org/licenses/OSL-3.0>

 UPGRADE NOTE:
   Do not edit or add to this file if you wish to upgrade AbanteCart to newer
   versions in the future. If you wish to customize AbanteCart for your
   needs please refer to http://www.AbanteCart.com for more information.
------------------------------------------------------------------------------*/
if (!defined('DIR_CORE') || !IS_ADMIN) {
	header('Location: static_pages/');
}
class ControllerResponsesListingGridRewardPoints extends AController {
	private $error = array();

	public function main() {

		//init controller data
		$this->extensions->hk_InitData($this, __FUNCTION__);

		$this->loadLanguage('reward_points/reward_points');
		//$this->loadModel('sale/order');

		$page = $this->request->post[ 'page' ]; // get the requested page
		$limit = $this->request->post[ 'rows' ]; // get how many rows we want to have into the grid
		$sidx = $this->request->post[ 'sidx' ]; // get index row - i.e. user click to sort
		$sord = $this->request->post[ 'sord' ]; // get the direction


		// process jGrid search parameter
		$allowedFields = array( 'customer_group_name', 'reward_points_amount', 'amount_modificator', 'combine_or_override' );
		$allowedSortFields = array( 'customer_group_name', 'reward_points_amount', 'amount_modificator', 'combine_or_override' );

		$allowedDirection = array( 'asc', 'desc' );

		if (!in_array($sidx, $allowedSortFields)) $sidx = $allowedSortFields[ 0 ];
		if (!in_array($sord, $allowedDirection)) $sord = $allowedDirection[ 0 ];

		$data = array(
			'sort' => $sidx,
			'order' => $sord,
			'start' => ($page - 1) * $limit,
			'limit' => $limit,
		);

		$this->loadLanguage('sale/customer_group');
		$this->loadModel('sale/customer_group');
		$this->loadModel('extension/reward_points');

		//Prepare filter config
		$grid_filter_params = array();
		$filter = new AFilter(array( 'method' => 'post', 'grid_filter_params' => $grid_filter_params ));

		$total = $this->model_sale_customer_group->getTotalCustomerGroups($filter->getFilterData());

		$response = new stdClass();
		$response->page = $filter->getParam('page');
		$response->total = $filter->calcTotalPages($total);
		$response->records = $total;
		$results = $this->model_sale_customer_group->getCustomerGroups($filter->getFilterData());

		$i = 0;
		foreach ($results as $result) {

			$object_id = isset($this->request->get['object_id']) ? $this->request->get['object_id'] : $result[ 'customer_group_id' ];
			$points_data = $this->model_extension_reward_points->getRewardPoints($result[ 'customer_group_id' ], $this->request->get['object_name'], $object_id);

			//echo_array($points_data);

			$points_amount = !isset($points_data[0]['amount']) ? 0 : $points_data[0]['amount'];
			$modificator = !isset($points_data[0]['amount_modificator']) ? 'a' : $points_data[0]['amount_modificator'];
			$combine = !isset($points_data[0]['combine']) ? 1 : $points_data[0]['combine'];

			$response->rows[ $i ][ 'id' ] = $result[ 'customer_group_id' ];
			$response->rows[ $i ][ 'cell' ] = array(
				$result[ 'name' ] . (($result[ 'customer_group_id' ] == $this->config->get('config_customer_group_id')) ? $this->language->get('text_default') : NULL),
				$this->html->buildInput(
					array(
						'name' => 'amount[' . $result[ 'customer_group_id' ] . ']',
						'value' => $points_amount,
					)
				),
				$this->html->buildSelectbox(
					array(
						'name' => 'amount_modificator[' . $result[ 'customer_group_id' ] . ']',
						'value' => $modificator,
						'options' => array('a' => $this->language->get('text_absolute'), 'p' => $this->language->get('text_percent')),
					)
				)
			);

			if ( $this->request->get['object_name'] == 'customer_group' ) {

				$response->rows[ $i ][ 'cell' ][] = $this->html->buildSelectbox(
					array(
						'name' => 'combine[' . $result[ 'customer_group_id' ] . ']',
						'value' => $combine,
						'options' => array($this->language->get('text_override'), $this->language->get('text_combine')),
					)
				);
			}
			$i++;
		}

		//update controller data
		$this->extensions->hk_UpdateData($this, __FUNCTION__);

		$this->load->library('json');
		$this->response->setOutput(AJson::encode($response));
	}

	public function update() {

		//init controller data
		$this->extensions->hk_InitData($this, __FUNCTION__);

		$this->loadModel('extension/reward_points');
		$this->loadLanguage('reward_points/reward_points');
		if (!$this->user->canModify('listing_grid/reward_points')) {
			$error = new AError('');
			return $error->toJSONResponse('NO_PERMISSIONS_402',
				array(
					'error_text' => sprintf($this->language->get('error_permission_modify'), 'listing_grid/reward_points'),
					'reset_value' => true
				));
		}

		switch ($this->request->post[ 'oper' ]) {
			case 'save':
				$ids = array_unique(explode(',', $this->request->post[ 'id' ]));
				if (!empty($ids))
					foreach ($ids as $id) {

						$object_id = isset($this->request->get['object_id']) ? $this->request->get['object_id'] : $id;

						$data = array(
							'customer_group_id' => $id,
							'amount' => $this->request->post['amount'][$id],
							'amount_modificator' => $this->request->post['amount_modificator'][$id],
							'combine' => $this->request->post['combine'][$id],
							'object_id' => $object_id,
							'object_name' => $this->request->get['object_name']
						);

						$result = $this->model_extension_reward_points->getRewardPoints($id, $this->request->get['object_name'], $object_id);
						if ( empty($result) ) {
							$this->model_extension_reward_points->addRewardPoints($data);
						} else {
							$this->model_extension_reward_points->updateRewardPoints($data);
						}
					}
				break;

			default:
				//echo_array($this->request->post);

		}

		//update controller data
		$this->extensions->hk_UpdateData($this, __FUNCTION__);
	}


	/**
	 * update only one field
	 *
	 * @return void
	 */
	public function update_field() {

		//init controller data
		$this->extensions->hk_InitData($this, __FUNCTION__);

		//echo_array($this->request->get);//exit;

		$this->loadModel('extension/reward_points');
		$this->loadLanguage('reward_points/reward_points');

		if (!$this->user->canModify('listing_grid/reward_points')) {
			$error = new AError('');
			return $error->toJSONResponse('NO_PERMISSIONS_402',
				array(
					'error_text' => sprintf($this->language->get('error_permission_modify'), 'listing_grid/reward_points'),
					'reset_value' => true
				)
			);
		}

		//request sent from jGrid. ID is key of array
		foreach ($this->request->post as $field => $value) {

			foreach ($value as $id => $v) {
				//$this->model_sale_order->editOrder($k, array( $field => $v ));

				$object_id = isset($this->request->get['object_id']) ? $this->request->get['object_id'] : $id;

				$data = array(
					'customer_group_id' => $id,
					'object_id' => $object_id,
					'object_name' => $this->request->get['object_name']
				);

				$data[$field] = $v;

				$result = $this->model_extension_reward_points->getRewardPoints($id, $this->request->get['object_name'], $object_id);
				if ( empty($result) ) {
					$this->model_extension_reward_points->addRewardPoints($data);
				} else {
					$this->model_extension_reward_points->updateRewardPoints($data);
				}
			}

		}

		//update controller data
		$this->extensions->hk_UpdateData($this, __FUNCTION__);
	}

	/*
	public function summary() {

		//update controller data
		$this->extensions->hk_InitData($this, __FUNCTION__);

		$this->loadLanguage('sale/order');
		$this->loadModel('sale/order');

		$response = new stdClass();

		if (isset($this->request->get[ 'order_id' ])) {
			$order_id = $this->request->get[ 'order_id' ];
		} else {
			$order_id = 0;
		}

		$order_info = $this->model_sale_order->getOrder($order_id);

		if (empty($order_info)) {
			$response->error = $this->language->get('error_order_load');
		} else {
			$response->order = array(
				'order_id' => '#' . $order_info[ 'order_id' ],
				'name' => $order_info[ 'firstname' ] . '' . $order_info[ 'lastname' ],
				'email' => $order_info[ 'email' ],
				'telephone' => $order_info[ 'telephone' ],
				'date_added' => date($this->language->get('date_format_short'), strtotime($order_info[ 'date_added' ])),
				'total' => $this->currency->format($order_info[ 'total' ], $order_info[ 'currency' ], $order_info[ 'value' ]),
				'order_status' => $order_info[ 'order_status_id' ],
				'shipping_method' => $order_info[ 'shipping_method' ],
				'payment_method' => $order_info[ 'payment_method' ],
			);

			if ($order_info[ 'customer_id' ]) {
				$response->order[ 'name' ] = '<a href="' . $this->html->getSecureURL('sale/customer/update', '&customer_id=' . $order_info[ 'customer_id' ]) . '">' . $response->order[ 'name' ] . '</a>';
			}

			$this->loadModel('localisation/order_status');
			$status = $this->model_localisation_order_status->getOrderStatus($order_info[ 'order_status_id' ]);
			if ($status)
				$response->order[ 'order_status' ] = $status[ 'name' ];

		}

		//update controller data
		$this->extensions->hk_UpdateData($this, __FUNCTION__);

		$this->load->library('json');
		$this->response->setOutput(AJson::encode($response));
	}
	*/
}